@@ -23,7 +23,7 @@
 #include "LinReg.h"
 #include <RcppArmadillo.h>
 
-#include <cstdio> 
+#include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <math.h>
@@ -44,43 +44,44 @@ using namespace LinReg;
 
 // LinReg() function callable from R via Rcpp::
 // [[Rcpp::export]]
-Rcpp::List LinReg_impl(arma::mat Data, unsigned long lNumber) {  
+Rcpp::List LinReg_impl(arma::mat Data, unsigned long lNumber) {
 
     long lIterates;
 
-    try {       
+    try {
         // Load observations -- or rather copy them in from R
         lIterates = Data.n_rows;
         data.y = Data.col(0);
         data.x = Data.col(1);
         mean_x = arma::sum(data.x)/lIterates;
-        
+
         //Initialise and run the sampler
-        smc::sampler<rad_state,smc::nullParams> Sampler(lNumber, HistoryType::RAM);  
-        smc::moveset<rad_state,smc::nullParams> Moveset(fInitialise, fMove, fMCMC);
-        
+		myMove = new LinReg_move;
+        smc::sampler<rad_state,smc::nullParams> Sampler(lNumber, HistoryType::RAM, myMove);
+
         Sampler.SetResampleParams(ResampleType::MULTINOMIAL, 0.5);
-        Sampler.SetMoveSet(Moveset);
         Sampler.SetMcmcRepeats(10);
         Sampler.Initialise();
         Sampler.IterateUntil(lIterates-1);
-        
+
         arma::mat theta(lNumber,3);
         arma::vec weights = Sampler.GetParticleWeight();
-        
+
         for (unsigned int i = 0; i<lNumber; i++){
             theta.row(i) = Sampler.GetParticleValueN(i).theta.t();
         }
-        
+
         double logNC = Sampler.GetLogNCPath();
-        
+
+		delete myMove;
+
         return Rcpp::List::create(Rcpp::Named("theta") = theta,Rcpp::Named("weights") = weights,
         Rcpp::Named("logNC") = logNC);
     }
     catch(smc::exception  e) {
         Rcpp::Rcout << e;
     }
-    return R_NilValue;              // to provide a return 
+    return R_NilValue;              // to provide a return
 }
 
 namespace LinReg {
@@ -88,7 +89,7 @@ namespace LinReg {
     ///The function corresponding to the log likelihood at specified time and position (up to normalisation)
 
     /// \param lTime        The current time (i.e. the index of the current distribution)
-    /// \param value        The state to consider 
+    /// \param value        The state to consider
     double logWeight(long lTime, const rad_state & value){
 
         double mean_reg = value.theta(0) + value.theta(1)*(data.x(lTime) - mean_x);
@@ -100,7 +101,7 @@ namespace LinReg {
     ///The function corresponding to the (unnormalised) log posterior at specified time and position
 
     /// \param lTime        The current time (i.e. the index of the current distribution)
-    /// \param value        The state to consider 
+    /// \param value        The state to consider
     double logPosterior(long lTime, const rad_state & value){
 
         double log_prior = -log(1000.0)- std::pow(value.theta(0) - 3000.0,2.0)/(2.0*1000.0*1000.0) -log(100.0)- std::pow(value.theta(1) - 185.0,2.0)/(2.0*100.0*100.0) + value.theta(2)-1.0/b_prior/expl(value.theta(2)) -value.theta(2)*(a_prior+1.0);
@@ -125,14 +126,14 @@ namespace LinReg {
     /// \param value        Reference to the empty particle value
     /// \param logweight    Refernce to the empty particle log weight
     /// \param param        Additional algorithm parameters
-    void fInitialise(rad_state & value, double & logweight, smc::nullParams & param)
+    void LinReg_move::pfInitialise(rad_state & value, double & logweight, smc::nullParams & param)
     {
         value.theta = arma::zeros(3);
         // drawing from the prior
         value.theta(0) = R::rnorm(3000.0,1000.0);
         value.theta(1) = R::rnorm(185.0,100.0);
         value.theta(2) = log(std::pow(R::rgamma(3,std::pow(2.0*300.0*300.0,-1.0)),-1.0));
-        
+
         logweight = logWeight(0, value);
     }
 
@@ -142,7 +143,7 @@ namespace LinReg {
     /// \param value        Reference to the current particle value
     /// \param logweight    Refernce to the current particle log weight
     /// \param param        Additional algorithm parameters
-    void fMove(long lTime, rad_state & value, double & logweight, smc::nullParams & param)
+    void LinReg_move::pfMove(long lTime, rad_state & value, double & logweight, smc::nullParams & param)
     {
         logweight += logWeight(lTime, value);
     }
@@ -153,17 +154,17 @@ namespace LinReg {
     /// \param value        Reference to the current particle value
     /// \param logweight    Reference to the log weight of the particle being moved
     /// \param param        Additional algorithm parameters
-    bool fMCMC(long lTime, rad_state & value, double & logweight, smc::nullParams & param)
+    bool LinReg_move::pfMCMC(long lTime, rad_state & value, double & logweight, smc::nullParams & param)
     {
         double logposterior_curr = logPosterior(lTime, value);
-        
+
         rad_state value_prop;
         value_prop.theta = value.theta + cholCovRW*Rcpp::as<arma::vec>(Rcpp::rnorm(3));
-        
+
         double logposterior_prop = logPosterior(lTime, value_prop);
-        
+
         double MH_ratio = exp(logposterior_prop - logposterior_curr);
-        
+
         if (MH_ratio>R::runif(0,1)){
             value = value_prop;
             logposterior_curr = logposterior_prop;
